***************************************************************
*** Group Liability Experiment
*** Author: Greg Fischer
*** August 24, 2007
***************************************************************
*** 
*** Revised 17 May 2011
***************************************************************
/*
Calculates treatment effect on NET transfers in regression framework
Also creates table 8B: Effect on net transfers when only one project succeeds
Table 9: Upside transfers
*/		

***************************************************************
*** SETUP
***************************************************************;
clear	
clear matrix						
capture log close				
set memory 100m					
set more off					


# delimit;

local doroot "$resDir\groupliability\";
cd "`doroot'";

local file = "T9_transUp";
local logfile = "logfiles\\`file'.log";
local filename ="`doroot'do\"+ "`file'.do";

di "filename: `filename'";

log using `logfile', replace;

use dtafiles\dataFinal, replace;

***************************************************************
*** Programs
***************************************************************;
cap prog drop fillt4;
program def fillt4;
	version 9.2;
	* This program fills a row of output table observations with regression results;
	* It works only for the standard table format in paper with;
	* Rows for contract type and columsn for limited information, full info and the difference;
	
	syntax, tableName(string) name(string) whichVar(string) i(real);
		replace `tableName'_Row = "`name'" if _n==`i';
		lincom r_`whichVar'_0 - r_`whichVar'_1;
		
		replace `tableName'_Lim = _b[r_`whichVar'_0] if _n==`i';
		replace `tableName'_Ful = _b[r_`whichVar'_1] if _n==`i';
		replace `tableName'_Dif = r(estimate) if _n==`i';
		
		local i = `i' + 1;
		replace `tableName'_Lim = _se[r_`whichVar'_0] if _n==`i';
		replace `tableName'_Ful = _se[r_`whichVar'_1] if _n==`i';
		replace `tableName'_Dif = r(se) if _n==`i';
	end;

cap prog drop fillRel;
program def fillRel;
	version 9.2;
	* This program fills rows of the output table with difference in regression coefficients;
	syntax, tableName(string) treat(string) rel(string) i(real);
		replace `tableName'_Row = "`treat' - `rel'" if _n==`i';
		lincom r_`treat'_0 - r_`rel'_0;
			replace `tableName'_Lim = r(estimate) if _n==`i';
			replace `tableName'_Lim = r(se) if _n==`i'+1;
		
		lincom r_`treat'_1 - r_`rel'_1;
			replace `tableName'_Ful = r(estimate) if _n==`i';
			replace `tableName'_Ful = r(se) if _n==`i'+1;
	end;


***************************************************************
*** MAIN
***************************************************************;
***************************************************************
*** Make Table 8: Effects of Contract Treatments on Transfers
***************************************************************;
local tableNameMac "NewT8";
gen str `tableNameMac'_Row="";
gen `tableNameMac'_Lim = .;
gen `tableNameMac'_Ful = .;
gen `tableNameMac'_Dif = .;

reg trans r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markRegTran==1, cluster(session);

replace `tableNameMac'_Row = "Individual Liability" if _n==1;
	replace `tableNameMac'_Ful = _b[r_indiv_1] if _n==1;
	replace `tableNameMac'_Ful = _se[r_indiv_1] if _n==2;
	replace `tableNameMac'_Dif = -_b[r_indiv_1] if _n==1;
	replace `tableNameMac'_Dif = _se[r_indiv_1] if _n==2;

fillt4, tableName(`tableNameMac') name(Joint Liability) whichVar(jl) i(4);
fillt4, tableName(`tableNameMac') name(Joint Liability with Approval) whichVar(jla) i(7);
fillt4, tableName(`tableNameMac') name(Equity) whichVar(eq) i(10);

* This manually calulates the difference between IL and JL with full info;
lincom r_indiv_1 - r_jl_1;
			replace `tableNameMac'_Ful = r(estimate) if _n==14;
			replace `tableNameMac'_Ful = r(se) if _n==15;
			
fillRel, tableName(`tableNameMac') treat(jla) rel(jl) i(16);
fillRel, tableName(`tableNameMac') treat(eq) rel(jl) i(18);

lincom r_indiv_1 - r_jla_1;
			replace `tableNameMac'_Ful = r(estimate) if _n==22;
			replace `tableNameMac'_Ful = r(se) if _n==23;
fillRel, tableName(`tableNameMac') treat(eq) rel(jla) i(24);

replace `tableNameMac'_Row = "Source: " + "`filename'" if _n == 28;
replace `tableNameMac'_Row = "Generated: `c(current_time)' `c(current_date)'" if _n == 29;

local outfile = "excel\\`tableNameMac'.out";
outsheet `tableNameMac'_* using `outfile' if _n<30, replace;

***************************************************************
*** Only 1 project succeeds
***************************************************************;
***************************************************************
*** Make Table 8B: Effects of Contract Treatments on Transfers when exactly 1 project succeeds
***************************************************************;

local tableNameMac "NewT8Only1";
gen str `tableNameMac'_Row="";
gen `tableNameMac'_Lim = .;
gen `tableNameMac'_Ful = .;
gen `tableNameMac'_Dif = .;

reg trans r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markRegTran==1 & ((stone+p_stone)==1), cluster(session);

replace `tableNameMac'_Row = "Individual Liability" if _n==1;
	replace `tableNameMac'_Ful = _b[r_indiv_1] if _n==1;
	replace `tableNameMac'_Ful = _se[r_indiv_1] if _n==2;
	replace `tableNameMac'_Dif = -_b[r_indiv_1] if _n==1;
	replace `tableNameMac'_Dif = _se[r_indiv_1] if _n==2;

fillt4, tableName(`tableNameMac') name(Joint Liability) whichVar(jl) i(4);
fillt4, tableName(`tableNameMac') name(Joint Liability with Approval) whichVar(jla) i(7);
fillt4, tableName(`tableNameMac') name(Equity) whichVar(eq) i(10);

* This manually calulates the difference between IL and JL with full info;
lincom r_indiv_1 - r_jl_1;
			replace `tableNameMac'_Ful = r(estimate) if _n==14;
			replace `tableNameMac'_Ful = r(se) if _n==15;
			
fillRel, tableName(`tableNameMac') treat(jla) rel(jl) i(16);
fillRel, tableName(`tableNameMac') treat(eq) rel(jl) i(18);

lincom r_indiv_1 - r_jla_1;
			replace `tableNameMac'_Ful = r(estimate) if _n==22;
			replace `tableNameMac'_Ful = r(se) if _n==23;
fillRel, tableName(`tableNameMac') treat(eq) rel(jla) i(24);

replace `tableNameMac'_Row = "Source: " + "`filename'" if _n == 28;
replace `tableNameMac'_Row = "Generated: `c(current_time)' `c(current_date)'" if _n == 29;

local outfile = "excel\\`tableNameMac'.out";
outsheet `tableNameMac'_* using `outfile' if _n<30, replace;

***************************************************************
*** UPSIDE TRANSFERS
***************************************************************;
***************************************************************
*** Make Table 9: Effects of Contract Treatments on Transfers when exactly 1 project succeeds
***************************************************************;

local tableNameMac "NewT9TransUp";
gen str `tableNameMac'_Row="";
gen `tableNameMac'_Lim = .;
gen `tableNameMac'_Ful = .;
gen `tableNameMac'_Dif = .;

local i = 1;
reg transUp r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 if markRegTran==1 & gameEff~=70 & stone==1, noc cluster(session);
	fillt4, tableName(`tableNameMac') name(Individual Liability) whichVar(indiv) i(`i');
		local i = `i' + 2;
	fillt4, tableName(`tableNameMac') name(Joint Liability) whichVar(jl) i(`i');
		local i = `i' + 2;
	fillt4, tableName(`tableNameMac') name(Joint Liability with Approval) whichVar(jla) i(`i');
		local i = `i' + 2;
	fillRel, tableName(`tableNameMac') treat(jl) rel(indiv) i(`i');
		local i = `i' + 4;

reg transUp r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 if markRegTran==1 & gameEff~=70 & risky==1 & stone==1, noc cluster(session);
	fillt4, tableName(`tableNameMac') name(Risky: Individual Liability) whichVar(indiv) i(`i');
		local i = `i' + 2;
	fillt4, tableName(`tableNameMac') name(Risky: Joint Liability) whichVar(jl) i(`i');
		local i = `i' + 2;
	fillt4, tableName(`tableNameMac') name(Risky: Joint Liability with Approval) whichVar(jla) i(`i');
		local i = `i' + 2;
	fillRel, tableName(`tableNameMac') treat(jl) rel(indiv) i(`i');
		local i = `i' + 4;
	
reg transUp r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 if markRegTran==1 & gameEff~=70 & risky==0 & stone==1, noc cluster(session);
	fillt4, tableName(`tableNameMac') name(Safe: Individual Liability) whichVar(indiv) i(`i');
		local i = `i' + 2;
	fillt4, tableName(`tableNameMac') name(Safe: Joint Liability) whichVar(jl) i(`i');
		local i = `i' + 2;
	fillt4, tableName(`tableNameMac') name(Safe: Joint Liability with Approval) whichVar(jla) i(`i');
		local i = `i' + 2;
	fillRel, tableName(`tableNameMac') treat(jl) rel(indiv) i(`i');
		local i = `i' + 4;

replace `tableNameMac'_Row = "Source: " + "`filename'" if _n == `i'; local i = `i'+1;
replace `tableNameMac'_Row = "Generated: `c(current_time)' `c(current_date)'" if _n == `i';

local outfile = "excel\\`tableNameMac'.out";
outsheet `tableNameMac'_* using `outfile' if _n<40, replace;

log close;
